{{/*
Полное имя приложения создается по правилу <имя helm-charts>-<имя инстанса>
<Имя инстанса> = Release.Name
*/}}
{{- define "store.fullname" -}}
{{- printf "%s-%s" .Chart.Name .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "store.labels" -}}
helm.sh/chart: {{ include "store.chart" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{ include "store.selectorLabels" . }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "store.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "store.selectorLabels" -}}
app: {{ include "store.fullname" . }}
run: store
{{- end }}

{{/*
Имя configMap store
*/}}
{{- define "store.proxy-config" -}}
{{- printf "%s-%s-%s" .Chart.Name .Release.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}


{{/*
имя wist сервера
*/}}
{{- define "wiststore.wist_fullname" -}}
{{- printf "%s-%s" "wist" .Release.Name | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "wiststore.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "wiststore.labels" -}}
helm.sh/chart: {{ include "wiststore.chart" . }}
{{ include "wiststore.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "wiststore.selectorLabels" -}}
app.kubernetes.io/instance: {{ .Release.Name }}
app: {{ include "wiststore.wist_fullname" . }}
run: wist
{{- end }}

{{/*
Имя configMap для wist
*/}}
{{- define "wiststore.wist-config" -}}
{{- printf "%s-%s-%s" "wist" .Release.Name "config" | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Return  the proper Storage Class
*/}}
{{- define "wiststore.storageClass" -}}
  {{- if .Values.persistence.storageClass -}}
      {{- if (eq "-" .Values.persistence.storageClass) -}}
          {{- printf "storageClassName: \"\"" -}}
      {{- else }}
          {{- printf "storageClassName: %s" .Values.persistence.storageClass -}}
      {{- end -}}
  {{- end -}}
{{- end -}}

{{/*
имя proxy сервера
*/}}
{{- define "wiststore.proxy_fullname" -}}
{{- printf "%s-%s" "proxy" .Release.Name  | trunc 63 | trimSuffix "-" }}
{{- end }}
